@@ -49,7 +49,6 @@ def init(path_to_find_bin, output_file_name, format):
     global _root_path, logger, _start_time
 
     _json_ext = ".json"
-    _yaml_ext = ".yaml"
     _start_time = datetime.now().strftime('%y%m%d_%H%M')
     _result_log = {
         "Tool Info": _PKG_NAME
@@ -72,11 +71,9 @@ def init(path_to_find_bin, output_file_name, format):
         else:
             if output_extension == _json_ext:
                 result_report = f"fosslight_opossum_{_start_time}"
-            elif output_extension == _yaml_ext:
-                result_report = f"fosslight-sbom-info_{_start_time}"
             else:
                 result_report = f"fosslight_report_{_start_time}"
-            bin_txt_file = f"binary_{_start_time}.txt"
+            bin_txt_file = f"fosslight_binary_{_start_time}.txt"
 
         result_report = os.path.join(output_path, result_report)
         binary_txt_file = os.path.join(output_path, bin_txt_file)
